import * as AWS from 'aws-sdk';
import { Tags } from 'handel-extension-api';
/**
 * Given a stack name, returns the stack, or null if it doesnt exist
 */
export declare function getStack(stackName: string): Promise<AWS.CloudFormation.Stack | null>;
/**
 * Waits for the given stack to be in the given state
 */
export declare function waitForStack(stackName: string, stackState: string): Promise<AWS.CloudFormation.Stack>;
/**
 * Given a stack name with template and parameters, creates the stack
 *
 * This method will wait for the stack to be in a create complete state
 * before resolving the promise
 */
export declare function createStack(stackName: string, templateBodyOrUrl: string, parameters: AWS.CloudFormation.Parameters, timeoutInMinutes: number, tags?: Tags | null): Promise<AWS.CloudFormation.Stack>;
/**
 * Given a stack name with template and parameters, updates the existing stack
 *
 * This method will wait for the stack to be in an update complete state
 * before resolving the promise.
 */
export declare function updateStack(stackName: string, templateBodyOrUrl: string, parameters: AWS.CloudFormation.Parameters, tags?: Tags | null): Promise<any>;
/**
 * Given a stack name, deletes the existing stack
 *
 * This method will wait for the stack to be in the delete complete state
 * before resolving the promise
 */
export declare function deleteStack(stackName: string): Promise<boolean>;
/**
 * Given a regular JavaScript object of key/value pairs, returns the corresponding
 * CloudFormation parameters representation.
 *
 * Example:
 * The object {
 *   myparam: 'myvalue'
 * }
 *
 * ...becomes the object {
 *   ParameterKey: 'myparam',
 *   ParameterValue: 'myvalue',
 *   UsePreviousValue: false
 * }
 *
 * @param {Object} parametersObj - The object with plain key/value pairs to be changed into CF-style parameters
 * @returns {Object} - The object contianing CloudFormation-style parameters
 */
export declare function getCfStyleStackParameters(parametersObj: any): AWS.CloudFormation.Parameters;
/**
 * Given a CloudFormation stack, get the output for the given key
 *
 * @param {string} outputKey - The name of the output value to get
 * @param {Object} cfStack - The CF stack object returned from the CloudFormation API
 * @returns {string} - Returns either the output if it is present, or null if it isn't
 */
export declare function getOutput(outputKey: string, cfStack: AWS.CloudFormation.Stack): string | null;
