import * as AWS from 'aws-sdk';
/**
 * Returns the information about the requested security group if it exists.
 */
export declare function getSecurityGroup(groupName: string, vpcId: string): Promise<AWS.EC2.SecurityGroup | null>;
/**
 * Given the ID of a security group and VPC, returns the information about that
 * security group, or null if it doesn't exist.
 */
export declare function getSecurityGroupById(groupId: string, vpcId: string): Promise<AWS.EC2.SecurityGroup | null>;
export declare function removeIngressFromSg(sourceSg: AWS.EC2.SecurityGroup, ownSg: AWS.EC2.SecurityGroup, protocol: string, fromPort: number, toPort: number, vpcId: string): Promise<boolean>;
/**
 * Given a security group, determines whether the given combination of protocol, start port,
 * end port, and source already exists as an ingress rule on the security group
 */
export declare function ingressRuleExists(securityGroup: AWS.EC2.SecurityGroup, startPort: number, endPort: number, protocol: string, sourceSg: AWS.EC2.SecurityGroup): boolean;
/**
 * Given a security group, adds an ingress rule from the given source security group
 * if that ingress rule doesn't already exist
 */
export declare function addIngressRuleToSgIfNotExists(sourceSg: AWS.EC2.SecurityGroup, destSg: AWS.EC2.SecurityGroup, protocol: string, startPort: number, endPort: number, vpcId: string): Promise<AWS.EC2.SecurityGroup | null>;
/**
 * Adds an ingress rule from the given source security group to the given
 * destination security group
 */
export declare function addIngressRuleToSecurityGroup(sourceSg: AWS.EC2.SecurityGroup, destSg: AWS.EC2.SecurityGroup, protocol: string, startPort: number, endPort: number, vpcId: string): Promise<AWS.EC2.SecurityGroup | null>;
