import { Tags } from 'handel-extension-api';
/**
 * Delete all objects with a matching prefix from the given bucket
 */
export declare function deleteMatchingPrefix(bucketName: string, prefix: string): Promise<AWS.S3.DeleteObjectOutput | null>;
/**
 * Lists the files in a bucket for the given key prefix
 *
 * This method isn't sufficient currently for huge numbers of files under
 * a given prefix, since it only returns the first 1000 objects.
 * For Handel's purposes this is probably fine, but may need to be
 * extended in the future if we start getting more than 1000 objects
 * under a given key prefix
 */
export declare function listFilesByPrefix(bucketName: string, keyPrefix: string): Promise<AWS.S3.Object[]>;
/**
 * Deletes the given objects from the S3 bucket
 */
export declare function deleteFiles(bucketName: string, objects: AWS.S3.Object[]): Promise<AWS.S3.DeleteObjectsOutput>;
/**
 * Cleans up all objects in a bucket with a certain key prefix that are
 * older than 30 days.
 *
 * This method keeps at least the 5 most recent objects, no matter how
 * old they are.
 */
export declare function cleanupOldVersionsOfFiles(bucketName: string, keyPrefix: string): Promise<AWS.S3.DeleteObjectsOutput | undefined>;
/**
 * Uploads the given file to a bucket with the given key
 */
export declare function uploadFile(bucketName: string, key: string, filePath: string): Promise<AWS.S3.ManagedUpload.SendData>;
export declare function uploadString(bucketName: string, key: string, content: string): Promise<AWS.S3.ManagedUpload.SendData>;
/**
 * Creates an S3 bucket in the given region
 */
export declare function createBucket(bucketName: string, region: string, tags?: Tags | null): Promise<AWS.S3.CreateBucketOutput>;
/**
 * Gets information about the S3 bucket with the given name
 */
export declare function getBucket(bucketName: string): Promise<AWS.S3.Bucket | null>;
/**
 * Creates the S3 bucket with the given name and region, or just
 * returns the information about the bucket if it already exists
 */
export declare function createBucketIfNotExists(bucketName: string, region: string, tags?: Tags | null): Promise<AWS.S3.Bucket | null>;
