"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2018 Brigham Young University
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const aws_wrapper_1 = require("./aws-wrapper");
function storeParameter(paramName, paramType, paramValue) {
    const putParams = {
        Name: paramName,
        Type: paramType,
        Value: paramValue,
        Description: 'Handel-injected parameter',
        Overwrite: true
    };
    return aws_wrapper_1.default.ssm.putParameter(putParams);
}
exports.storeParameter = storeParameter;
/**
 * Given a list of parameter names, deletes those parameters
 */
function deleteParameters(parameterNames) {
    return __awaiter(this, void 0, void 0, function* () {
        const deletePromises = [];
        for (const parameterName of parameterNames) {
            const deleteParams = {
                Name: parameterName
            };
            deletePromises.push(aws_wrapper_1.default.ssm.deleteParameter(deleteParams));
        }
        try {
            yield Promise.all(deletePromises);
            return true;
        }
        catch (err) {
            // If the param is already gone we won't count it as an error
            if (err.code === 'ParameterNotFound') {
                return true;
            }
            else {
                throw err;
            }
        }
    });
}
exports.deleteParameters = deleteParameters;
//# sourceMappingURL=ssm-calls.js.map