"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2018 Brigham Young University
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const handel_extension_api_1 = require("handel-extension-api");
const cloudformationCalls = require("../aws/cloudformation-calls");
const ec2Calls = require("../aws/ec2-calls");
const s3Calls = require("../aws/s3-calls");
const ssmCalls = require("../aws/ssm-calls");
function deleteSecurityGroupForService(stackName) {
    return __awaiter(this, void 0, void 0, function* () {
        const sgName = `${stackName}-sg`;
        const stack = yield cloudformationCalls.getStack(sgName);
        if (stack) {
            return cloudformationCalls.deleteStack(sgName);
        }
        else {
            return true;
        }
    });
}
function unDeployService(serviceContext, serviceType) {
    return __awaiter(this, void 0, void 0, function* () {
        const accountConfig = serviceContext.accountConfig;
        const stackName = serviceContext.stackName();
        // Delete stack if needed
        const stack = yield cloudformationCalls.getStack(stackName);
        if (stack) {
            yield cloudformationCalls.deleteStack(stackName);
        }
        // Cleanup uploaded S3 files for service
        const name = {
            bucket: `handel-${accountConfig.region}-${accountConfig.account_id}`,
            prefix: `${serviceContext.appName}/${serviceContext.environmentName}/${serviceContext.serviceName}`
        };
        yield s3Calls.deleteMatchingPrefix(name.bucket, name.prefix);
        return new handel_extension_api_1.UnDeployContext(serviceContext);
    });
}
exports.unDeployService = unDeployService;
function unPreDeploySecurityGroup(ownServiceContext, serviceName) {
    return __awaiter(this, void 0, void 0, function* () {
        const sgName = ownServiceContext.stackName();
        yield deleteSecurityGroupForService(sgName);
        return new handel_extension_api_1.UnPreDeployContext(ownServiceContext);
    });
}
exports.unPreDeploySecurityGroup = unPreDeploySecurityGroup;
function unBindService(ownServiceContext, ownPreDeployContext, dependentOfServiceContext, dependentOfPreDeployContext, protocol, port) {
    return __awaiter(this, void 0, void 0, function* () {
        if (ownPreDeployContext.securityGroups.length > 0 && dependentOfPreDeployContext.securityGroups.length > 0) { // Only try to remove ingress if it hasn't been deleted yet
            const ownSg = ownPreDeployContext.securityGroups[0];
            const sourceSg = dependentOfPreDeployContext.securityGroups[0];
            let portsToUnBind;
            if (port instanceof Array) {
                portsToUnBind = port;
            }
            else {
                portsToUnBind = [port];
            }
            for (const portToUnBind of portsToUnBind) {
                yield ec2Calls.removeIngressFromSg(sourceSg, ownSg, protocol, portToUnBind, portToUnBind, ownServiceContext.accountConfig.vpc);
            }
        }
        return new handel_extension_api_1.UnBindContext(ownServiceContext, dependentOfServiceContext);
    });
}
exports.unBindService = unBindService;
function deleteServiceItemsFromSSMParameterStore(ownServiceContext, paramsToDelete) {
    return __awaiter(this, void 0, void 0, function* () {
        const paramsToDeleteFullNames = paramsToDelete.map(paramToDelete => ownServiceContext.ssmParamName(paramToDelete));
        return yield ssmCalls.deleteParameters(paramsToDeleteFullNames);
    });
}
exports.deleteServiceItemsFromSSMParameterStore = deleteServiceItemsFromSSMParameterStore;
//# sourceMappingURL=delete-phases.js.map