"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2018 Brigham Young University
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const handel_extension_api_1 = require("handel-extension-api");
const cloudformationCalls = require("../aws/cloudformation-calls");
const ec2Calls = require("../aws/ec2-calls");
const handlebarsUtils = require("../util/handlebars-utils");
const deployPhase = require("./deploy-phase");
const tagging_1 = require("./tagging");
function getSgStackName(ownServiceContext) {
    return `${ownServiceContext.stackName()}-sg`;
}
function createSecurityGroupForService(sgName, sshBastionIngressPort, serviceContext, tags) {
    return __awaiter(this, void 0, void 0, function* () {
        const accountConfig = serviceContext.accountConfig;
        const handlebarsParams = {
            groupName: sgName,
            vpcId: accountConfig.vpc
        };
        if (sshBastionIngressPort) {
            handlebarsParams.sshBastionSg = accountConfig.ssh_bastion_sg;
            handlebarsParams.sshBastionIngressPort = sshBastionIngressPort;
        }
        // Compile and upload template
        const compiledTemplate = yield handlebarsUtils.compileTemplate(`${__dirname}/ec2-sg-template.yml`, handlebarsParams);
        const s3ObjectData = yield deployPhase.uploadCFTemplateToHandelBucket(serviceContext, compiledTemplate);
        // Create/update stack
        const stack = yield cloudformationCalls.getStack(sgName);
        let deployedStack;
        if (!stack) {
            deployedStack = yield cloudformationCalls.createStack(sgName, s3ObjectData.Location, [], 30, tags);
        }
        else {
            deployedStack = yield cloudformationCalls.updateStack(sgName, s3ObjectData.Location, [], tags);
        }
        const groupId = cloudformationCalls.getOutput('GroupId', deployedStack);
        return ec2Calls.getSecurityGroupById(groupId, accountConfig.vpc);
    });
}
function preDeployCreateSecurityGroup(serviceContext, sshBastionIngressPort, serviceName) {
    return __awaiter(this, void 0, void 0, function* () {
        const sgName = getSgStackName(serviceContext);
        const securityGroup = yield createSecurityGroupForService(sgName, sshBastionIngressPort, serviceContext, tagging_1.getTags(serviceContext));
        if (!securityGroup) {
            throw new Error(`Did not get back security group '${sgName}' after creating it`);
        }
        const preDeployContext = new handel_extension_api_1.PreDeployContext(serviceContext);
        preDeployContext.securityGroups.push(securityGroup);
        return preDeployContext;
    });
}
exports.preDeployCreateSecurityGroup = preDeployCreateSecurityGroup;
function getSecurityGroup(serviceContext) {
    return __awaiter(this, void 0, void 0, function* () {
        const preDeployContext = new handel_extension_api_1.PreDeployContext(serviceContext);
        const accountConfig = serviceContext.accountConfig;
        const sgName = getSgStackName(serviceContext);
        const stack = yield cloudformationCalls.getStack(sgName);
        if (stack) {
            const groupId = cloudformationCalls.getOutput('GroupId', stack);
            if (!groupId) {
                throw new Error('CloudFormation stack didnt return security group id');
            }
            const securityGroup = yield ec2Calls.getSecurityGroupById(groupId, accountConfig.vpc);
            if (!securityGroup) {
                throw new Error('Could not find security group referenced in CloudFormation stack. Was it deleted manually outside of CloudFormation?');
            }
            preDeployContext.securityGroups.push(securityGroup);
        }
        return preDeployContext;
    });
}
exports.getSecurityGroup = getSecurityGroup;
//# sourceMappingURL=pre-deploy-phase.js.map