"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2018 Brigham Young University
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const archiver = require("archiver");
const fs = require("fs");
const pascalCase = require("pascal-case");
/**
 * Turns a string into a valid CloudFormation Logical ID
 * @param id
 * @returns {string}
 */
function normalizeLogicalId(id) {
    return pascalCase(id, undefined, true);
}
exports.normalizeLogicalId = normalizeLogicalId;
/**
 * Takes the given directory path and zips it up and stores it
 *   in the given file path
 */
function zipDirectoryToFile(directoryPath, filePath) {
    return new Promise((resolve, reject) => {
        if (!fs.existsSync(directoryPath)) {
            throw new Error(`Directory path to be zipped does not exist: ${directoryPath}`);
        }
        const archive = archiver.create('zip', {});
        const output = fs.createWriteStream(filePath);
        archive.pipe(output);
        archive.directory(directoryPath, ''); // The 2nd param makes all the files just be included at the root with no directory
        archive.finalize();
        output.on('close', () => {
            resolve();
        });
        output.on('error', (err) => {
            reject(err);
        });
    });
}
exports.zipDirectoryToFile = zipDirectoryToFile;
//# sourceMappingURL=util.js.map